================
Red10 Python API
================

The standalone python client for using: https://redten.io

For more information:

#. `Intro`_
#. `Forecast`_
#. `Predictions with the IRIS dataset`_

.. _Intro: https://redten.io:8101/RedTen-Intro.slides.html#/
.. _Forecast: https://redten.io:8103/RT-Price-Forecast.slides.html#/
.. _Predictions with the IRIS dataset: https://redten.io:8102/RT-Run-IRIS.slides.html#/

=======
Version
=======

1.0.0

================
Release Commands
================

#. Upload to pypitest:

::

    python setup.py sdist upload -r pypitest

#. Upload to pypi:

::

    python setup.py sdist upload -r pypi
